Dropinity<FullResponse, Model> class

main Dropinity class

Inheritance
Available extensions

Constructors

Dropinity({Key? key, bool enableMultiSelection = false, Widget multiSelectionItemBuilder(BuildContext context, Model element)?, FutureOr<void> onListChanged(List<Model> values)?, List<Model> initialValues = const [], Curve curve = Curves.linear, FutureOr<void> onCollapse()?, FutureOr<void> onExpand()?, AutovalidateMode? autoValidateMode, Widget errorWidget(String errorMsg)?, Color listBackgroundColor = Colors.white, Widget? dropdownTitle, TextFieldData<Model>? textFieldData, String? validator(Model?)?, double? listHeight, required DropinityController controller, required ButtonData<Model> buttonData, required List<Model>? values, required ValuesData<Model>? valuesData, required FutureOr<void> onChanged(Model val), bool showNoDataAlert = false, bool maintainState = false})
normal constructor for local dropdown
const
Dropinity.withApiRequest({Key? key, bool enableMultiSelection = false, Widget multiSelectionItemBuilder(BuildContext context, Model element)?, FutureOr<void> onListChanged(List<Model> values)?, List<Model> initialValues = const [], bool maintainState = false, bool showNoDataAlert = false, String? validator(Model?)?, AutovalidateMode? autoValidateMode, Widget errorWidget(String errorMsg)?, Curve curve = Curves.linear, Color listBackgroundColor = Colors.white, Widget? dropdownTitle, TextFieldData<Model>? textFieldData, double? listHeight, required DropinityController controller, required ButtonData<Model> buttonData, required DropinityPagifyData<FullResponse, Model>? pagifyData, required FutureOr<void> onChanged(Model val), FutureOr<void> onCollapse()?, FutureOr<void> onExpand()?})
constructor for api dropdown
const

Properties

autoValidateMode AutovalidateMode?
validation mode of validator AutovalidateMode
final
buttonData ButtonData<Model>
button data ButtonData
final
controller DropinityController
controller of the dropdown DropinityController
final
curve Curve
animation of the list result Curve
final
title of the dropdown
final
enableMultiSelection bool
multi selection option bool
final
errorWidget Widget Function(String errorMsg)?
error builder Widget
final
hashCode int
The hash code for this object.
no setterinherited
initialValues List<Model>
initial values for multi selection
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listBackgroundColor Color
Background Color of the list result Color
final
listHeight double?
height of the list result double
final
maintainState bool
keep state on memory bool
final
multiSelectionItemBuilder Widget Function(BuildContext context, Model element)?
the single item which is selected in multi selection
final
onChanged FutureOr<void> Function(Model val)
callback when current element changes
final
onCollapse FutureOr<void> Function()?
onCollapse callback Function
final
onExpand FutureOr<void> Function()?
onExpand callback Function
final
onListChanged FutureOr<void> Function(List<Model> values)?
callback when list changes
final
pagifyData DropinityPagifyData<FullResponse, Model>?
custom pagify data DropinityPagifyData comes from Pagify package
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNoDataAlert bool
no more data flag bool
final
textFieldData TextFieldData<Model>?
text field data TextFieldData
final
validator String? Function(Model?)?
Dropinity custom validator
final
values List<Model>?
values of the dropdown when local
final
valuesData ValuesData<Model>?
values of the dropdown when local which includes itemBuilder
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Dropinity<FullResponse, Model>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) Widget

Available on Widget, provided by the PaddingExtension extension

padding extension to apply padding to this widget at all
paddingEnd(double padding) Widget

Available on Widget, provided by the PaddingExtension extension

padding extension to apply padding to this widget at End
paddingTop(double padding) Widget

Available on Widget, provided by the PaddingExtension extension

padding extension to apply padding to this widget at Top
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited