onReadCache property

List<Map<String, dynamic>>? Function(String key)? onReadCache
getter/setter pair

Called to restore items from cache when a request fails. Return null or an empty list if no cache exists.

Implementation

List<Map<String, dynamic>>? Function(String key)? onReadCache;